@@ -11,7 +11,6 @@ def _print(*args, **kwargs):
     sep = kwargs.get('sep', ' ')
     end = kwargs.get('end', '\n')
     f   = kwargs.get('file', sys.stdout)
-    parts = [str(item) for item in args ]
     parts.append(end)
     f.write(sep.join(parts))
     
@@ -35,6 +34,6 @@ def test_six_print_example(capsys):
     
 def test_docs_example():    
     u = six.u('both em\u2014and&#x2013;dashes&hellip;')
-    ne = named_entities(u)
-    assert ne == 'both em&mdash;and&ndash;dashes&hellip;'
-    assert unescape(ne) == six.u('both em\u2014and\u2013dashes\u2026')
+    assert named_entities(u)   == 'both em&mdash;and&ndash;dashes&hellip;'
+    assert numeric_entities(u) == 'both em&#8212;and&#8211;dashes&#8230;'
+    assert unescape(u)   == six.u('both em\u2014and\u2013dashes\u2026')
